@@ -4,7 +4,7 @@ name = "pyvcam"
 hwid = []
 
 class instrument:
-    def __init__(self,serial_number):
+    def __init__(self,port):
         pvc.init_pvcam()  # Initialize PVCAM
         try:
             self.cam = next(Camera.detect_camera())  # Use generator to find first camera
