@@ -17,7 +17,6 @@ class Instrument:
 class InstrumentWrapper(param.Parameterized):
     instrument_selected = param.ObjectSelector()
     button = pn.widgets.Button(name='Reload devices', button_type='primary')
-    button2 = pn.widgets.Button(name="Initialize instrument", button_type='primary')
     initialized = False
 
     def __init__(self, modules, name):
@@ -29,10 +28,11 @@ class InstrumentWrapper(param.Parameterized):
         self.hwids = [self.modules[i]["hwid"] for i in self.modules]
         self.reload_devices()
         self.button.on_click(self.reload_devices)
-        self.button2.on_click(self.initialize)
-        if "software_software" in self.devices.keys():
+        devices = list(self.devices.keys())
+        if "software_software" in devices:
             self.instrument_selected = "software_software"
-            self.load_device()
+        elif len(devices) > 0:
+            self.instrument_selected = devices[0]
 
     def reload_devices(self, event=None, debug=False):
         ports = find_ports()
@@ -50,16 +50,14 @@ class InstrumentWrapper(param.Parameterized):
                             print(hwid)
                             print(port.hwid.split(" ")[1].replace("VID:PID=", ""))
                         if str(hwid) == port.hwid.split(" ")[1].replace("VID:PID=", ""):
-                            name = f"{port.serial_number} - {port.name} - {mname} - {port.name}"
-                            self.devices[name] = {"name": port.name, "hwid": port.hwid,
-                                                  "serial_number": port.serial_number, "module": module, "port": port}
+                            if port.serial_number in module["serial"] or module["serial"] is "any":
+                                name = f"{port.serial_number} - {port.name} - {mname} - {port.name}"
+                                self.devices[name] = {"name": port.name, "hwid": port.hwid,
+                                                      "serial_number": port.serial_number, "module": module,
+                                                      "port": port}
         self.param["instrument_selected"].objects = self.devices.keys()
 
-    def initialize(self, event=None):
-        if self.instrument_selected == None:
-            self.instrument_selected = list(self.devices.keys())[0]
-        self.load_device()
-
+    @param.depends("instrument_selected", watch=True)
     def load_device(self):
         module = self.devices[self.instrument_selected]["module"]
         self.instrument = self.modules[module]["module"].instrument(
@@ -68,7 +66,7 @@ class InstrumentWrapper(param.Parameterized):
 
     def view(self):
 
-        return pn.Column(self.param, self.button, self.button2)
+        return pn.Column(self.param, self.button)
 
     def serve(self):
         self.view().show(port=5006)
